clear
set more off
set mem 100m
*generating 02_EXPALCH.dta
cd "C:\Africa\Ghana\GLSS3-1991"
*---------------------------------------------
use "02_CLEANDATA\S9B", clear
des
*total observations 104,068
*--------------------------------------------
*HID
egen HID= concat( clust nh), p(/)
*---------------------------------------------
tab fdexpcd, miss
/*CHECK : Consistently coded - Item codes have values from 99 to 107.
No missing values.*/
*---------------------------------------------
*dropping the observations that do not relate to alcoholic beverages and tobacco
keep if fdexpcd>=99 & fdexpcd<=107
des
*number of observations 3,918
*---------------------------------------------
*generating the total amount of expenditure during the 11 survey visits
egen amt = rowtotal(s9bq1 s9bq2 s9bq3 s9bq4 s9bq5 s9bq6 s9bq7 s9bq8 s9bq9 s9bq10)
*------------------------------------------------------
*Merging BASICINFO to ascertain rural or urban location
sort HID
merge HID using 04_AGGDATA\00_BASICINFO
tab _merge
/*Correctly merged
2= 2,292
3= 3,918*/ 
drop _merge
sort HID
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a 33 day period in urban and 16 day period in rural areas.
11 visits at 3 day intervals 30 days in urban areas
8 visits at 2 day intervals 14 days in rural areas
For annualizing multiply the expenditure by 
(365/30) in urban areas and 
(365/14) in rural areas.*/
gen az_amt=(amt*(365/14)) if RURURB==1
replace az_amt=(amt*(365/30)) if RURURB==2
*---------------------------------------------
*FDALC_B
gen FDALC_B = az_amt if (fdexpcd>=99 & fdexpcd<=104)
*---------------------------------------------
*TOBACCO
gen TOBACCO = az_amt if (fdexpcd>=105 & fdexpcd<=107)
*---------------------------------------------
collapse (sum)FDALC_B TOBACCO, by (HID)
sort HID
des
*total observations 4,523
save 04_AGGDATA\EXPALCH, replace
*----------------------------------------------------
use "02_CLEANDATA\S8H", clear
des
*number of observations 32,052
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 3,070
*----------------------------------------------------
tab  homagrcd, miss
/*CHECK : Consistently coded - Item codes have values from 1 to 91.
No missing values.*/
*----------------------------------------------------
*dropping the observations that do not relate to alcoholic beverages and tobacco
keep if homagrcd==90
des
*number of observations 78
*----------------------------------------------------
*generating the total number of units consumed during the 11 or 8 survey visits
egen qty= rowtotal(s8hq3 s8hq4 s8hq5 s8hq6 s8hq7 s8hq8 s8hq9 s8hq10 s8hq11 s8hq12)
gen amt1=qty*s8hq14
*------------------------------------------------------
*Merging BASICINFO to ascertain rural or urban location
sort HID
merge HID using 04_AGGDATA\00_BASICINFO
tab _merge
/*Correctly merged
2= 4,445
3= 78*/ 
drop _merge
sort HID
*----------------------------------------------------
/*Annualizing the value
Home produced food may be eaten throughout the year or only for a few months.
CHECK: Months of consumption and whether or not consumed at home.*/
tab	s8hq2 s8hq1, miss
/*CHECK: Inconsistently coded
1. 11 observations coded as 'NO' were consumed for certain months.
2. 93 observations coded as 'YES' but were consumed for 0 months.
3. 32 observations coded as 'YES' but values for months consumed ==.
Number of months for items in Category 1 has been recoded as system missing (.)
Number of months for items in Category 2 and 3 have been left unaltered.*/
replace s8hq2=. if s8hq2==2
/*The survey captures expenditure over a 33 day period in urban areas 
and a 16 day period in rural areas
11 visits at 3 day intervals= 30 days
8 visits at 2 day intervals= 14 days*/
gen az_amt1=amt1*(s8hq2*30)/30 if RURURB==2
replace az_amt1=amt1*(s8hq2*30)/14 if RURURB==1
*s8hq2 is the number of months the produce was consumed
*----------------------------------------------------
*FDALC_P
gen FDALC_P = az_amt1 
collapse (sum)FDALC_P, by (HID)
sort HID
des
*number of observations 4,523
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPALCH
tab _merge
/*Correctly merged
3= 4,523*/ 
drop _merge
sort HID
*------------------------------------------------------
*NARCOTICS
gen NARCOTICS=.
*No data on narcotics
*------------------------------------------------------
*TOTALCH
egen TOTALCH =rowtotal(FDALC_B FDALC_P TOBACCO NARCOTICS)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var FDALC_B "Total expenditure on purchased alcoholic beverages"
label var FDALC_P "Total value of alcoholic beverages other than purchased"
label var TOBACCO "Total (expenditure on/value of)(tobacco/tobacco products)(purchased/received/produced)"
label var NARCOTICS "Total (expenditure on/value of)(narcotics/narcotics products)(purchased/received/produced)"
label var TOTALCH "Total expenditure on alcoholic beverages, tobacco, and narcotics)"
*------------------------------------------------------
order HID FDALC_B FDALC_P TOBACCO NARCOTICS TOTALCH 
keep HID FDALC_B FDALC_P TOBACCO NARCOTICS TOTALCH
des
*number of observations 4,523
sort HID
save 04_AGGDATA\02_EXPALCH, replace
erase 04_AGGDATA\EXPALCH.dta
