clear
set more off
set mem 100m
*generating 04_EXPHOUS.dta
cd "C:\Africa\Ghana\GLSS3-1991"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in S9A2.
LESS-FREQUENT is captured in S9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\S9A2", clear
des
*Number of observations 37,901
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 4,510
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=308 & nfdex2cd<=313)
des
*number of observations 6,809
*---------------------------------------------
*generating the total amount of expenditure during the 11 or 8 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6 s9a2q7 s9a2q8 s9a2q9 s9a2q10)
*------------------------------------------------------
*Merging BASICINFO to ascertain rural or urban location
sort HID
merge HID using 04_AGGDATA\00_BASICINFO
tab _merge
/*Correctly merged
2= 269; 
3= 6,809*/
drop _merge
sort HID
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a :-
30 day period in urban areas
164day period in rural areas*/
gen az_amt=amt*365/14 if RURURB==1
replace az_amt=amt*365/30 if RURURB==2
*---------------------------------------------
*hswater_9A2
gen hswater_9A2 = az_amt if nfdex2cd==308
*---------------------------------------------
*HSFUEL
gen HSFUEL= az_amt if (nfdex2cd>=312 & nfdex2cd<=313)
*---------------------------------------------
*GAS
gen GAS= az_amt if nfdex2cd==310
*---------------------------------------------
*ELEC
gen ELEC= .
*---------------------------------------------
*HSUTILITY
egen HSUTILITY = rowtotal(GAS ELEC)
*---------------------------------------------
*HSDIESEL
gen HSDIESEL= .
*---------------------------------------------
*HSKEROSENE
gen HSKEROSENE= az_amt if nfdex2cd==311
*---------------------------------------------
collapse (sum)hswater_9A2 HSUTILITY GAS ELEC HSKEROSENE HSDIESEL HSFUEL, by (HID)
sort HID
des
*total observations 4,523
save 04_AGGDATA\EXPHOUS, replace
*----------------------------------------------------
use "02_CLEANDATA\S9A12", clear
des
*number of observations 55,996
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 4,487
*----------------------------------------------------
tab  nfdex1cd, miss
*The item codes are consistently coded.
*----------------------------------------------------
*CHECK: Expenditure is recorded either on an annual basis or on a quarterly basis
count if s9a1q3!=. & s9a1q4==.
*54,628 observations
count if s9a1q3==. & s9a1q4!=.
*1,103 observations
count if s9a1q3==. & s9a1q4==.
*16 observations
count if s9a1q3!=. & s9a1q4!=.
*249 observations
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/* CLEANING ASSUMPTIONS: 249 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 168 observations have meaningful values for s9a1q3, 
but corresponding value for s9a1q4 is 0.
(b) 1 observation has a meaningful value for s9a1q4,
but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c) 4 observations have equivalent annualized values for s9a1q3 and s9a1q4.
That is s9a1q3=(4 * s9a1q4). In these, the value of s9a1q4 has been replaced by 0.*/
replace s9a1q4=0 if s9a1q3==(s9a1q4*4) ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(d)7 observations have equal values for s9a1q3 and s9a1q4.
In these, the value of s9a1q4 has been replaced by 0.*/
replace s9a1q4=0 if s9a1q3==s9a1q4 ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(e)For 6 observations with very low annual values (s9a1q3<=1000 cedis), 
it is assumed that quarterly values (s9a1q4) are correct. 
In these cases the annual values (s9a1q3) are replaced by 0.*/
replace s9a1q3=0 if (s9a1q3<=1000 & s9a1q3<=s9a1q4) ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(f)For the remaining 63 observations it is assumed that the annual values are correct. 
In these cases the quarterly values (s9a1q4) are replaced by 0.*/
replace s9a1q4=0 if (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=303 & nfdex1cd<=307)
des
*number of observations 3,283
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*RENT_ACT
gen RENT_ACT = az_amt if (nfdex1cd>=303 & nfdex1cd<=304)
*----------------------------------------------------
*hswater_9A12
gen hswater_9A12 = az_amt if nfdex1cd==307
*----------------------------------------------------
collapse (sum)RENT_ACT hswater_9A12, by (HID)
sort HID
des
*number of observations 3,075
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPHOUS
tab _merge
/*Correctly merged
1= 1 : A household dropped while generating BASICINFO
2= 1,477; 
3= 3,075*/
drop if _merge==1
drop _merge
sort HID
*------------------------------------------------------
*HSWATER
egen HSWATER=rowtotal(hswater_9A2 hswater_9A12)
*------------------------------------------------------
*RENT_IMP
gen RENT_IMP=.
*------------------------------------------------------
*HSREPAIR
gen HSREPAIR=.
*------------------------------------------------------
*TOTHOUS
egen TOTHOUS =rowtotal(HSREPAIR HSWATER HSUTILITY HSKEROSENE HSDIESEL HSFUEL)
*Does not include RENT_ACT and RENT_IMP
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var RENT_ACT "Actual rentals for housing"
label var RENT_IMP "Imputed rentals for housing - SAME AS OWNER OCCUPIED HOUSING RENT"
label var HSREPAIR "Expenditure on maintenance and repair of dwelling"
label var HSWATER "Expenditure on water supply and miscellaneous services related to dwelling"
label var HSFUEL "Expenditure on firewood charcoal and other fuel"
label var GAS "Expenditure on cooking gas"
label var ELEC "Expenditure on electricity"
label var HSKEROSENE "Expenditure on kerosene"
label var HSDIESEL "Expenditure on diesel for non-transportation purposes"
label var HSUTILITY "Expenditure on electricity and gas"
label var TOTHOUS "Total expenditure on housing"
*------------------------------------------------------
order HID RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY TOTHOUS
keep HID RENT_ACT RENT_IMP HSREPAIR HSWATER HSFUEL GAS ELEC HSKEROSENE HSDIESEL HSUTILITY TOTHOUS
des
*number of observations 4,523
sort HID
save 04_AGGDATA\04_EXPHOUS,replace
erase 04_AGGDATA\EXPHOUS.dta
