clear
set more off
set mem 100m
*generating 07_EXPTRSP.dta
cd "C:\Africa\Ghana\GLSS3-1991"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in S9A2.
LESS-FREQUENT is captured in S9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\S9A2", clear
des
*Number of observations 37,901
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 4,501
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=605 & nfdex2cd<=612)
des
*number of observations 3,051
*---------------------------------------------
*generating the total amount of expenditure during the 11 or 8 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6 s9a2q7 s9a2q8 s9a2q9 s9a2q10)
*------------------------------------------------------
*Merging BASICINFO to ascertain rural or urban location
sort HID
merge HID using 04_AGGDATA\00_BASICINFO
tab _merge
/*Correctly merged
2= 1,899; 
3= 3,051*/
drop _merge
sort HID
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a :-
30 day period in urban areas(11*3)
14 day period in rural areas(8*2)*/
gen az_amt=amt*365/14 if RURURB==1
replace az_amt=amt*365/30 if RURURB==2
*---------------------------------------------
*trperson_9A2
gen trperson_9A2 = az_amt if (nfdex2cd==605|nfdex2cd==609)
*---------------------------------------------
*TRFUEL
gen TRFUEL = az_amt if nfdex2cd==608
*---------------------------------------------
*TRSERVE
gen TRSERVE = az_amt if nfdex2cd>=610 & nfdex2cd<=612
*---------------------------------------------
collapse (sum)trperson_9A2 TRFUEL TRSERVE, by (HID)
sort HID
des
*total observations 4,552
save 04_AGGDATA\EXPTRSP, replace
*----------------------------------------------------
use "02_CLEANDATA\S9A12", clear
des
*number of observations 55,996
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 4,487
*----------------------------------------------------
tab  nfdex1cd, miss
/*CHECK: Consistently coded, no observations with item code 412 (AC, Air Cooler)
; No missing values.*/
*----------------------------------------------------
*CHECK: Expenditure is recorded either on an annual basis or on a quarterly basis
count if s9a1q3!=. & s9a1q4==.
*54,628 observations
count if s9a1q3==. & s9a1q4!=.
*1,103 observations
count if s9a1q3==. & s9a1q4==.
*16 observations
count if s9a1q3!=. & s9a1q4!=.
*249 observations
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/* CLEANING ASSUMPTIONS: 249 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 168 observations have meaningful values for s9a1q3, 
but corresponding value for s9a1q4 is 0.
(b) 1 observation has a meaningful value for s9a1q4,
but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c) 4 observations have equivalent annualized values for s9a1q3 and s9a1q4.
That is s9a1q3=(4 * s9a1q4). In these, the value of s9a1q4 has been replaced by 0.*/
replace s9a1q4=0 if s9a1q3==(s9a1q4*4) ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(d)7 observations have equal values for s9a1q3 and s9a1q4.
In these, the value of s9a1q4 has been replaced by 0.*/
replace s9a1q4=0 if s9a1q3==s9a1q4 ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(e)For 6 observations with very low annual values (s9a1q3<=1000 cedis), 
it is assumed that quarterly values (s9a1q4) are correct. 
In these cases the annual values (s9a1q3) are replaced by 0.*/
replace s9a1q3=0 if (s9a1q3<=1000 & s9a1q3<=s9a1q4) ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(f)For the remaining 63 observations it is assumed that the annual values are correct. 
In these cases the quarterly values (s9a1q4) are replaced by 0.*/
replace s9a1q4=0 if (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=601 & nfdex1cd<=604)
des
*number of observations 539
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*VEHICLES
gen VEHICLES = az_amt if (nfdex1cd>=601 & nfdex1cd<=603)
*BICYCLES have been included in VEHICLES
*----------------------------------------------------
*trperson_9A12
gen trperson_9A12 = az_amt if nfdex1cd==604
*----------------------------------------------------
collapse (sum)VEHICLES trperson_9A12, by (HID)
sort HID
des
*number of observations 400
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPTRSP
tab _merge
/*Correctly merged
2= 4,123; 
3= 400*/
drop _merge
sort HID
*------------------------------------------------------
*TRPERSON
egen TRPERSON=rowtotal(trperson_9A2 trperson_9A12)
*------------------------------------------------------
*TOTTRSP
egen TOTTRSP =rowtotal(TRFUEL TRPERSON TRSERVE)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var VEHICLES "Purchase of vehicles"
label var TRPERSON "Expenditure on personal transport equipment/repairs/chauffeurs etc."
label var TRFUEL "Transportation fuel"
label var TRSERVE "Expenditure on public transportation/airfare etc."
label var TOTTRSP "Total expenditure on transport"
*------------------------------------------------------
order HID VEHICLES TRFUEL TRPERSON TRSERVE TOTTRSP
keep HID VEHICLES TRFUEL TRPERSON TRSERVE TOTTRSP
des
*number of observations 4,523
sort HID
save 04_AGGDATA\07_EXPTRSP, replace
erase 04_AGGDATA\EXPTRSP.dta
