clear
set more off
set mem 100m
*generating 08_EXPCMNQ.dta
cd "C:\Africa\Ghana\GLSS3-1991"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in S9A2.
LESS-FREQUENT is captured in S9A12. 
THERE ARE NO LESS-FREQUENT EXPENDITURES RELATED TO COMMUNICATION.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\S9A2", clear
des
*Number of observations 37,901
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=613 & nfdex2cd<=614)
des
*number of observations 210
*---------------------------------------------
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 202
*---------------------------------------------
*generating the total amount of expenditure during the 11 or 8 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6 s9a2q7 s9a2q8 s9a2q9 s9a2q10)
*------------------------------------------------------
*Merging BASICINFO to ascertain rural or urban location
sort HID
merge HID using 04_AGGDATA\00_BASICINFO
tab _merge
/*Correctly merged
2= 4,321; 
3= 210*/
drop _merge
sort HID
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a :-
30 day period in urban areas(11*3)
14 day period in rural areas(8*2)*/
gen az_amt=amt*365/14 if RURURB==1
replace az_amt=amt*365/30 if RURURB==2
*---------------------------------------------
*COMPOST
gen COMPOST = az_amt if nfdex2cd==613
*---------------------------------------------
*COMSERVE
gen COMSERVE = az_amt if nfdex2cd==614
*---------------------------------------------
collapse (sum)COMPOST COMSERVE, by (HID)
sort HID
des
*total observations 4,523
*------------------------------------------------------
*COMTEL
gen COMTEL=.
*------------------------------------------------------
*TOTCMNQ
egen TOTCMNQ =rowtotal(COMPOST COMSERVE COMTEL)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var COMPOST "Expenditure on postal services"
label var COMSERVE "Expenditure on telephone and telefax services"
label var COMTEL "Expenditure on telephone, telefax and internet services"
label var TOTCMNQ "Total expenditure on communication"
*------------------------------------------------------
order HID COMPOST COMSERVE COMTEL TOTCMNQ
keep HID COMPOST COMSERVE COMTEL TOTCMNQ
des
*number of observations 4,523
sort HID
save 04_AGGDATA\08_EXPCMNQ, replace
