clear
set more off
set mem 100m
*generating 09_EXPRCRE.dta
cd "C:\Africa\Ghana\GLSS3-1991"
*---------------------------------------------
/*Non-food expenditure is classified as FREQUENT and LESS-FREQUENT.
FREQUENT is captured in S9A2.
LESS-FREQUENT is captured in S9A12.
The item codes are designed to be mutually exclusive in both these sections in the codebook.
It needs to be checked if they are consistently coded in the dataset.*/
*---------------------------------------------
use "02_CLEANDATA\S9A2", clear
des
*Number of observations 37,901
*---------------------------------------------
*HID
egen HID= concat( clust nh), p(/)
codebook HID
*number of households 4,510
*---------------------------------------------
*Checking the item codes
tab nfdex2cd, miss
*Consistently coded
*---------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex2cd>=707 & nfdex2cd<=713)|nfdex2cd==805
/*Items defined as 'writing and drawing equipment and supplies' and 
grouped under miscellaneous goods and services 
have been regrouped under recreational expenditure.*/
des
*number of observations 2,414
*---------------------------------------------
*generating the total amount of expenditure during the 11 or 8 survey visits
egen amt = rowtotal(s9a2q1 s9a2q2 s9a2q3 s9a2q4 s9a2q5 s9a2q6 s9a2q7 s9a2q8 s9a2q9 s9a2q10)
*------------------------------------------------------
*Merging BASICINFO to ascertain rural or urban location
sort HID
merge HID using 04_AGGDATA\00_BASICINFO
tab _merge
/*Correctly merged
2= 2,662; 
3= 2,414*/
drop _merge
sort HID
*---------------------------------------------
/*Annualizing the value
The survey captures expenditure over a :-
30 day period in urban areas
14 day period in rural areas*/
gen az_amt=(amt*(365/14)) if RURURB==1
replace az_amt=(amt*(365/30)) if RURURB==2
*---------------------------------------------
*rcaudi_9A2
gen rcaudi_9A2 = az_amt if nfdex2cd==707
*---------------------------------------------
*RCSERVE
gen RCSERVE = az_amt if nfdex2cd>=708 & nfdex2cd<=711
*---------------------------------------------
*RCNEWS
gen RCNEWS = az_amt if (nfdex2cd>=712 & nfdex2cd<=713)|nfdex2cd==805
*---------------------------------------------
collapse (sum)rcaudi_9A2 RCSERVE RCNEWS, by (HID)
sort HID
des
*total observations 4,523
save 04_AGGDATA\EXPRCRE, replace
*----------------------------------------------------
use "02_CLEANDATA\S9A12", clear
des
*number of observations 55,996
*----------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*unique hid values 4,487
*----------------------------------------------------
tab  nfdex1cd, miss
/*CHECK: Consistently coded, no observations with item code 412 (AC, Air Cooler)
; No missing values.*/
*----------------------------------------------------
*CHECK: Expenditure is recorded either on an annual basis or on a quarterly basis
count if s9a1q3!=. & s9a1q4==.
*54,628 observations
count if s9a1q3==. & s9a1q4!=.
*1,103 observations
count if s9a1q3==. & s9a1q4==.
*16 observations
count if s9a1q3!=. & s9a1q4!=.
*249 observations
tab s9a1q3 s9a1q4 if (s9a1q3!=. & s9a1q4!=.)
/* CLEANING ASSUMPTIONS: 249 observations have non-missing values for both s9a1q3 and s9a1q4. Of these:-
(a) 168 observations have meaningful values for s9a1q3, 
but corresponding value for s9a1q4 is 0.
(b) 1 observation has a meaningful value for s9a1q4,
but corresponding value for s9a1q3 is 0.
These codes have been left unchanged since they will not affect aggregation.
(c) 4 observations have equivalent annualized values for s9a1q3 and s9a1q4.
That is s9a1q3=(4 * s9a1q4). In these, the value of s9a1q4 has been replaced by 0.*/
replace s9a1q4=0 if s9a1q3==(s9a1q4*4) ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(d)7 observations have equal values for s9a1q3 and s9a1q4.
In these, the value of s9a1q4 has been replaced by 0.*/
replace s9a1q4=0 if s9a1q3==s9a1q4 ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(e)For 6 observations with very low annual values (s9a1q3<=1000 cedis), 
it is assumed that quarterly values (s9a1q4) are correct. 
In these cases the annual values (s9a1q3) are replaced by 0.*/
replace s9a1q3=0 if (s9a1q3<=1000 & s9a1q3<=s9a1q4) ///
	& (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
/*(f)For the remaining 63 observations it is assumed that the annual values are correct. 
In these cases the quarterly values (s9a1q4) are replaced by 0.*/
replace s9a1q4=0 if (s9a1q3!=. & s9a1q4!=.) ///
	& (s9a1q3!=0 & s9a1q4!=0)
*----------------------------------------------------
*dropping all observations that do not relate to this expenditure head
keep if (nfdex1cd>=701 & nfdex1cd<=706)
des
*number of observations 596
*----------------------------------------------------
/*Annualizing the value
The survey captures expenditure over either an annual or a quarterly period.
Quarterly expenditure is multiplied by 4*/
gen amt= s9a1q4 * 4
egen az_amt= rowtotal(s9a1q3 amt)
*----------------------------------------------------
*rcaudi_9A12
gen rcaudi_9A12 = az_amt 
*----------------------------------------------------
collapse (sum)rcaudi_9A12, by (HID)
sort HID
des
*number of observations 528
*------------------------------------------------------
merge HID using 04_AGGDATA\EXPRCRE
tab _merge
/*Correctly merged
2= 3,995 ; 
3= 528*/
drop _merge
sort HID
*------------------------------------------------------
*RCAUDI
egen RCAUDI = rowtotal(rcaudi_9A2 rcaudi_9A12)
*------------------------------------------------------
*DURRC
gen DURRC = .
*------------------------------------------------------
*RCPETS
gen RCPETS = .
*------------------------------------------------------
*RCHOLID
gen RCHOLID = .
*------------------------------------------------------
*TOTRCRE
egen TOTRCRE = rowtotal(RCAUDI RCPETS RCSERVE RCNEWS RCHOLID)
*------------------------------------------------------
*labeling the variables
label var HID "Household unique ID"
label var RCAUDI "Expenditure on audio-visual, photographic and information processing equipment"
label var DURRC "Expenditure on other major durables for recreation and culture"
label var RCPETS "Expenditure on other recreational items and equipment, gardens and pets"
label var RCSERVE "Expenditure on recreational and cultural services, such as movies etc."
label var RCNEWS "Expenditure on newspapers, books and stationary of non-educational purpose"
label var RCHOLID "Expenditure on package holidays"
label var TOTRCRE "Total expenditure on recreation"
*------------------------------------------------------
order HID RCAUDI DURRC RCPETS RCSERVE RCNEWS RCHOLID TOTRCRE
keep HID RCAUDI DURRC RCPETS RCSERVE RCNEWS RCHOLID TOTRCRE
des
*number of observations 4,523
sort HID
save 04_AGGDATA\09_EXPRCRE, replace
erase 04_AGGDATA\EXPRCRE.dta
