clear
clear matrix
set more off
set mem 100m
*generating GHA_1991_I.dta
cd "C:\Africa\Ghana\GLSS3-1991"
*---------------------------------------------
use "04_AGGDATA\00_BASICINFO",clear
sort HID
save "04_AGGDATA\GHA_I",replace
*---------------------------------------------
use "02_CLEANDATA\S0A.dta", clear
des
/*Number of observations 4,552
Household level file
Contains basic and survey visit data*/ 
*---------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*4,552 unique values generated
*---------------------------------------------
sort HID
merge HID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
1=29 : 29 additional households that do not have complete data and were
dropped while generating BASICINFO
3=4,523*/
drop if _merge==1
drop _merge
*---------------------------------------------
*PROVINCE
gen PROVINCE=.
*no data
*---------------------------------------------
*DISTRICT
gen DISTRICT=.
*---------------------------------------------
sort HID
save 04_AGGDATA\GHA_I, replace
*---------------------------------------------
use"02_CLEANDATA\S1", clear
des
/*Number of observations 20,403
Individual level file for all individuals 
Contains basic individual information*/ 
*---------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*4,552 unique values generated
*---------------------------------------------
sort HID
merge HID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
1=142 : from the 29 households that were dropped in BASICINFO
3=20,261*/
drop if _merge==1
drop _merge
codebook HID
*CHECK: There are 4,523 households
*---------------------------------------------
*INDID
tab pid, miss
*CHECK: Consistently coded; No missing values
egen INDID = concat(pid)
*---------------------------------------------
*SEX
tab sex, miss
*CHECK: Consistently coded; No missing values
recode sex (1=1)(2=0),gen(SEX)
*---------------------------------------------
*RELAT
tab rel, miss
*CHECK: Consistently coded; No missing values
recode  rel (1=1)(2=2)(3=3)(4=5)(5=4)(6=7)(7 8=8)(9=9), gen (RELAT)
*no observations coded as 6 "son/daughter in law" since the data does not allow it.
tab SEX RELAT, miss
/*CHECK: Inconsistently coded- 3 households do not have heads while 1 household has 2 individuals coded as head.
No missing values. */
replace RELAT=1 if HID=="3762/10" & agey==60
*HID # 3762/10 has 2 members, both female, one aged 11yrs and the other aged 60 yrs
replace RELAT=1 if HID=="3243/13" & agey==15
*HID # 3243/13 has 3 members, 2 females and one male, the male is eldest aged 15 yrs
replace RELAT=1 if HID=="3195/29" & agey==32
*HID # 3195/29 has 3 members, all females, the eldest female is aged 32 years
replace RELAT=2 if HID=="3679/3" & INDID=="2" & SEX==0 & agey==20
*HID # 3679/3 has 2 heads-one female and 1 male; the female is younger and is recoded to spouse.
tab SEX RELAT, miss
/*CHECK: Consistently coded; No missing values;
2. There are 4,523 head of household of which 1,455 are female.
3. There are 2,552 spouses of which 21 are male*/
*---------------------------------------------
*HEAD
gen HEAD = 0
replace HEAD = 1 if RELAT==1
tab HEAD, miss
/*CHECK: Consistently coded - 4,523 heads; No missing values.*/
*---------------------------------------------
*SP_PRES
tab s1q8, miss
/*CHECK: Consistently coded; 14,138 missing values*/ 
recode s1q8 (1=1)(2=0), gen (SP_PRES)
*---------------------------------------------
*AGEY
tab agey, miss
/*CHECK: Consistently coded- 13 observations coded as 99;
No missing values.*/
gen AGEY = agey
replace AGEY=98 if (AGEY>=99 & AGEY!=.)
*---------------------------------------------
*AGEM
tab agey agem, miss
/*CHECK: Inconsisently coded - agem has also been coded for individuals above age 5, 
whereas according to the survey questionnaire it should have been coded only for children 
below or equal to 5 yrs old;
16,213 missing values for agem */
gen months = (agey * 12) if agey<=5
egen AGEM=rowtotal(months agem) if agey<=5
replace AGEM=. if AGEM>60
tab AGEM, miss
/*CHECK:Consistently coded; 16,682 missing values
1. 3,579 individuals are aged 5 years and below*/
*---------------------------------------------
*ETHNICITY
gen ETHNICITY=.
*no data
*---------------------------------------------
*LANGUAGE
gen LANGUAGE=.
*no data
*---------------------------------------------
*RELIGION
gen RELIGION = .
*no data
*---------------------------------------------
*MARSTAT
*Marital status is coded only for individuals more than 15 years old
tab mar, miss
/*CHECK: Consistently coded; 9,552 missing values*/
recode mar (1=2)(2=4)(3=5)(4=6)(5=1), gen (MARSTAT)
*Married individuals (2) need to be further classified as monogamous or polygamous
/*CHECK - checking for consistency between MARSTAT and RELAT*/
tab MARSTAT RELAT, miss
/* CHECK - Inconsistent coding
1. 2 individuals reported never married and were spouses.
2. 2 individuals did not report marital status but were spouses.
The marital status of the above individuals is recoded to 2'married monogamous*/
replace MARSTAT=2 if (MARSTAT==1|MARSTAT==.) & RELAT==2 
/*CHECK - checking for polygamy/polyandry*/
bysort HID:egen spouses=count(RELAT) if RELAT==2
/*This generates number of spouses only for individuals that reported to be spouses
Replacing this value for household heads as well.*/
bysort HID:egen polygamy=mean(spouses) if (RELAT==1|RELAT==2) 
tab polygamy, miss
*CHECK - Consistently coded
replace MARSTAT=3 if (polygamy>1 & polygamy!=.)&(RELAT==1|RELAT==2)
tab MARSTAT RELAT, miss
/*CHECK - Consistently coded - 504 polygamous households*/
/*CHECK - Checking SP_PRES against MARSTAT*/
tab SP_PRES MARSTAT, miss
/*CHECK - Inconsistently coded-
1. 9 individuals responded to SP_PRES when they were MARSTAT=1'never married'
2. 8 individuals responded to SP_PRES when they were MARSTAT=5'Divorced/separated'
3. 5 individuals responded to SP_PRES when they were MARSTAT=6'widowed'
4. 4 individuals responded to SP_PRES when they were MARSTAT=.
For these 26 observations the value of SP_PRES has been recoded as system miss*/
replace SP_PRES=. if (MARSTAT==1|MARSTAT==5|MARSTAT==6|MARSTAT==.)
tab SP_PRES, miss
*CHECK - Consistently coded;14,164 missing values
*---------------------------------------------
sort HID INDID
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\S2", clear
des
/*Number of observations 17,168
Individual level file for individuals aged 5yrs or more
Contains education data*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*number of households 4,551
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
*EVERATTD
tab s2q1, miss
/*CHECK: Consistently coded-5,898 individual never attended school; 
No missing observations*/
recode s2q1 (1=1)(2=0) ,gen (EVERATTD)
*-------------------------------------------------
*ATSCHOOL
tab s2q4, miss
/*CHECK: Consistently coded; 
5,908 missing values including 5,898 individual who never attended school.*/
recode s2q4 (1=1)(2=0), gen(ATSCHOOL)
tab ATSCHOOL EVERATTD, m
replace ATSCHOOL=0 if ATSCHOOL==. & EVERATTD!=.
*Replacing EVERATTD as yes if ATSCHOOL is yes
replace EVERATTD=1 if EVERATTD==0 & ATSCHOOL==1
*-------------------------------------------------
*EDLEVEL_AR
tab s2q2, miss
/*CHECK: It is a string variable; Consistently coded; 
6,390 missing values including 5,989 individual who never attended school.*/
gen EDLEVEL_AR=0 if s2q2=="NONE"
replace EDLEVEL_AR=1 if (s2q2=="A1"|s2q2=="A2"|s2q2=="P1"|s2q2=="P2"|s2q2=="P3"|s2q2=="P4"|s2q2=="P5")
replace EDLEVEL_AR=2 if (s2q2=="P6"| ///
	s2q2=="JSS1"|s2q2=="JSS2"| ///
	s2q2=="S1"|s2q2=="S2")
replace EDLEVEL_AR=3 if (s2q2=="JSS3"| ///
	s2q2=="M1"|s2q2=="M2"|s2q2=="M3"| ///
	s2q2=="PS1"|s2q2=="PS2"|s2q2=="PS3"| ///
	s2q2=="S3"|s2q2=="S4")
replace EDLEVEL_AR=4 if (s2q2=="M4"|s2q2=="S5")
replace EDLEVEL_AR=5 if (s2q2=="T1"|s2q2=="T2"|s2q2=="T3"|s2q2=="T4")
replace EDLEVEL_AR=6 if (s2q2=="U1"|s2q2=="U2"|s2q2=="U3"|s2q2=="U4"| ///
	s2q2=="U5"|s2q2=="U6"|s2q2=="U7"|s2q2=="U8")
replace EDLEVEL_AR=9 if s2q2=="K"
*Koranic education is classified as 9 "other"
replace EDLEVEL_AR=0 if EVERATTD==0
replace EDLEVEL_AR=7 if (s2q45==1 & (EDLEVEL_AR==.|EDLEVEL_AR==0))
tab EDLEVEL_AR, miss
/*CHECK: Consistently coded; 494 missing values
Refer to excel sheet in directory DOC for code conversion.*/
*-------------------------------------------------
*EDYEARS_AT
tab s2q2 if ATSCHOOL==1, miss
gen EDYEARS_AT=0 if ((s2q2=="NONE"|s2q2=="") & ATSCHOOL==1)
replace EDYEARS_AT=1 if (s2q2=="P1" & ATSCHOOL==1)
replace EDYEARS_AT=2 if (s2q2=="P2" & ATSCHOOL==1)
replace EDYEARS_AT=3 if (s2q2=="P3" & ATSCHOOL==1)
replace EDYEARS_AT=4 if (s2q2=="P4" & ATSCHOOL==1)
replace EDYEARS_AT=5 if (s2q2=="P5" & ATSCHOOL==1)
replace EDYEARS_AT=6 if ((s2q2=="P6"|s2q2=="K") & ATSCHOOL==1)
*Individuals with Koranic education are assumed to have 6 years of education equivalent to primary education.
replace EDYEARS_AT=7 if ((s2q2=="JSS1"|s2q2=="PS1"|s2q2=="S1") & ATSCHOOL==1)
replace EDYEARS_AT=8 if ((s2q2=="JSS2"|s2q2=="PS2"|s2q2=="S2") & ATSCHOOL==1)
replace EDYEARS_AT=9 if ((s2q2=="JSS3"|s2q2=="PS3"|s2q2=="S3") & ATSCHOOL==1)
replace EDYEARS_AT=10 if ((s2q2=="M1"|s2q2=="S4"|s2q2=="T1") & ATSCHOOL==1)
replace EDYEARS_AT=11 if ((s2q2=="M2"|s2q2=="S5"|s2q2=="T2") & ATSCHOOL==1)
replace EDYEARS_AT=12 if ((s2q2=="M3"|s2q2=="U1"|s2q2=="T3") & ATSCHOOL==1)
replace EDYEARS_AT=13 if ((s2q2=="M4"|s2q2=="U2"|s2q2=="T4") & ATSCHOOL==1)
replace EDYEARS_AT=14 if (s2q2=="U3" & ATSCHOOL==1)
replace EDYEARS_AT=15 if (s2q2=="U4" & ATSCHOOL==1)
replace EDYEARS_AT=16 if (s2q2=="U5" & ATSCHOOL==1)
replace EDYEARS_AT=17 if (s2q2=="U6" & ATSCHOOL==1)
replace EDYEARS_AT=18 if (s2q2=="U7" & ATSCHOOL==1)
replace EDYEARS_AT=19 if (s2q2=="U8" & ATSCHOOL==1)
tab EDYEARS_AT, m
/*CHECK: Consistently coded; 11,197 missing values.*/
*-------------------------------------------------
*EDYEARS
gen EDYEARS=0 if (s2q2=="NONE"|s2q2=="")
replace EDYEARS=1 if s2q2=="P1"
replace EDYEARS=2 if s2q2=="P2"
replace EDYEARS=3 if s2q2=="P3"
replace EDYEARS=4 if s2q2=="P4"
replace EDYEARS=5 if s2q2=="P5"
replace EDYEARS=6 if (s2q2=="P6"|s2q2=="K")
*Individuals with Koranic education are assumed to have 6 years of education equivalent to primary education.
replace EDYEARS=7 if (s2q2=="JSS1"|s2q2=="PS1"|s2q2=="S1")
replace EDYEARS=8 if (s2q2=="JSS2"|s2q2=="PS2"|s2q2=="S2")
replace EDYEARS=9 if (s2q2=="JSS3"|s2q2=="PS3"|s2q2=="S3")
replace EDYEARS=10 if (s2q2=="M1"|s2q2=="S4"|s2q2=="T1")
replace EDYEARS=11 if (s2q2=="M2"|s2q2=="S5"|s2q2=="T2")
replace EDYEARS=12 if (s2q2=="M3"|s2q2=="U1"|s2q2=="T3")
replace EDYEARS=13 if (s2q2=="M4"|s2q2=="U2"|s2q2=="T4")
replace EDYEARS=14 if s2q2=="U3"
replace EDYEARS=15 if s2q2=="U4"
replace EDYEARS=16 if s2q2=="U5"
replace EDYEARS=17 if s2q2=="U6"
replace EDYEARS=18 if s2q2=="U7"
replace EDYEARS=19 if s2q2=="U8"
replace EDYEARS=(EDYEARS_AT - 1) if (EDYEARS_AT>0 & EDYEARS_AT<.)
tab EDYEARS, m
/*CHECK: Consistently coded; 78 missing values.*/
*-------------------------------------------------
*SCHLTYP
tab s2q25, miss
*CHECK: Consistently coded; 6141 missing values
tab s2q31, miss
*CHECK: Consistently coded; 11,575 missing values
recode s2q25 (1=1)(2=2),gen (SCHLTYP)
replace SCHLTYP=1 if s2q31==1
replace SCHLTYP=1 if s2q31==2
replace SCHLTYP=. if ATSCHOOL==0
tab SCHLTYP ATSCHOOL, miss
tab SCHLTYP, miss
/*CHECK: Consistently coded; 11,295 missing values
1. Nothing is coded as 9 'Other'*/
*-------------------------------------------------
*LITERACY
tab s2q40, miss
*CHECK - Consistently coded;8,251 missing values
tab s2q42, miss
*CHECK - Consistently coded;8,257 missing values
tab s2q44, miss
*CHECK - Consistently coded;8,257 missing values
tab s2q45, miss
*CHECK - Consistently coded;8,259 missing values
tab s2q41, miss
*CHECK - Consistently coded;8,250 missing values
tab s2q43, miss
*CHECK - Consistently coded;8,254 missing values
gen LITERACY =1 if (s2q40==1|s2q42==1|s2q44==1|s2q45==1|(s2q41!=0 & s2q41!=.)|(s2q43!=0 & s2q43!=.))
replace LITERACY = 2 if (s2q40==2 & s2q42==2 & s2q44==2 & s2q45==2 & s2q41==0 & s2q43==0)
replace LITERACY = . if (s2q40==. & s2q42==. & s2q44==. & s2q45==. & s2q41==. & s2q43==.)
replace LITERACY = 1 if (EDLEVEL_AR>=3 & EDLEVEL_AR<=9)
/*Individuals have been considered literate if they have responded	that they
can eihter read or write or have completed primary education and above or 'other' education/literacy program*/
/*tab LITERACY AGEY if AGEY<=5, miss
*CHECK: Inconsistent coding.
replace LITERACY = . if AGEY<=5*/
*LITERACY for children aged 5 years or less have been recoded as missing
*No observations have been coded as 3
tab LITERACY,miss
*CHECK - Consistently coded;3,914 missing values
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*Correctly merged
1=126
2=3,219
3=17,042*/
drop if _merge==1
drop _merge
*-------------------------------------------------
sort HID INDID
des
*number of observations 20,261
codebook HID
*number of households 4,523
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\S3A", clear
des
/*Number of observations 20,302
Individual level file for all individuals
Contains information regarding health*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
codebook HID
*number of households 4,545
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
*MORB_TR
gen MORB_TR= 2
*-------------------------------------------------
*MORBID
tab s3aq1, miss
*CHECK: Consistently coded; No missing values.
recode s3aq1 (2 3 4= 1)(1=0),gen (MORBID)
*-------------------------------------------------
*RTREATM
tab s3aq6, miss
*CHECK: Consistently coded; 10 missing values.
recode s3aq6 (1=1)(2=0),gen (RTREATM)
*-------------------------------------------------
*HLTHFAC
tab s3aq9 if RTREATM==1, miss
*CHECK: Consistently coded; 6 missing values if the individual sought medical attention.
tab s3aq8a if RTREATM==1, miss
*CHECK: Only the first visit has been used; Consistently coded; 1 missing value if the individual sought medical attention.
recode s3aq9 (1=1)(4=2)(2 5 6=3)(3=5)(9=9), gen (HLTHFAC)
replace HLTHFAC=6 if (s3aq8a==1|s3aq8a==8|s3aq8a==9)
replace HLTHFAC=. if RTREATM!=1
tab HLTHFAC, miss
/*CHECK: Consistently coded
1. Nothing is coded as 4 "Outreach";
18,011 missing values*/
*-------------------------------------------------
*OWHPROVD
tab s3aq10, miss
*CHECK: Consistently coded; 18,008 missing values
tab s3aq8a, miss
*CHECK: Only the first visit has been used; Consistently coded; 18,003 missing values.
recode s3aq10 (1=1)(2=2), gen(OWHPROVD)
replace OWHPROVD=3 if (s3aq8a==1|s3aq8a==8)
replace OWHPROVD=4 if s3aq8a==9
replace OWHPROVD=9 if (OWHPROVD!=1 & s3aq8a==10)
replace OWHPROVD=. if HLTHFAC==.
tab OWHPROVD, miss
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
1= 142
2= 101
3= 20,160*/
drop if _merge==1
drop _merge
*-------------------------------------------------
sort HID INDID
des
*number of observations 20,261
codebook HID
*number of households 4,523
save 04_AGGDATA\GHA_I, replace
*-------------------------------------------------
use "02_CLEANDATA\S3B", clear
des
/*Number of observations 5,307
Individual level file for individuals aged below 7 yrs 
Contains information regarding vaccination*/ 
*-------------------------------------------------
*HID
egen HID = concat(clust nh), p(/)
*-------------------------------------------------
*INDID
egen INDID = concat(pid)
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
1= 38
2= 14,992
3= 5,269*/
drop if _merge==1
drop _merge
*-------------------------------------------------
*keeping observations only for children below 5 years of age
keep if AGEM<=60
des
*Number of observations 3,579
*-------------------------------------------------
*WHDELIV
gen WHDELIV=.
*no data
*-------------------------------------------------
*VCARD
tab s3bq1, miss
*CHECK: Consistently coded; 28 missing values
tab s3bq2, miss
*CHECK: Consistently coded; 672 missing values
recode s3bq2 (1=1)(2=2),gen (VCARD)
replace VCARD=2 if (VCARD==2 & s3bq1==1)
replace VCARD=3 if ((VCARD==2|VCARD==.) & s3bq1==2)
tab VCARD, miss
*CHECK: Consistently coded; 37 missing values
*-------------------------------------------------
*BCG
tab s3bq3d, miss
*CHECK: Consistently coded; 1,414 missing values
tab s3bq3d s3bq4d, miss
/*CHECK: Consistently coded - 
s3bq4d is coded only if s3bq3d is missing except 2 observations*/
recode s3bq3d (1=1)(2 3 4=0), gen (BCG)
replace BCG=1 if (s3bq4d==1 & s3bq3d==.)
replace BCG=0 if ((s3bq4d==2|s3bq4d==3|s3bq4d==5) & s3bq3d==.)
replace BCG=9 if (s3bq4d==4 & s3bq3d==.)
tab BCG, miss
/*CHECK: Consistently coded; 666 missing values
1. Incomplete immunization has been coded as 0'No'
2. Responses as N/A has been coded as 0'No'*/
*-------------------------------------------------
*POLIO_DO
tab s3bq3b, miss
*CHECK: Consistently coded; 1,412 missing values
tab s3bq4b, miss
*CHECK: Consistently coded; 2,828 missing values
tab s3bq3b s3bq4b, miss
/*CHECK: Consistently coded - 
s3bq4b is coded only if s3bq3b is missing except 2 observations*/
gen POLIO_DO = 0 if (s3bq3b==3|s3bq3b==4)
replace POLIO_DO=0 if (s3bq3b==. & (s3bq4b==3|s3bq4b==5))
replace POLIO_DO=3 if s3bq3b==1
replace POLIO_DO=3 if (s3bq3b==. & s3bq4b==1)
replace POLIO_DO=9 if s3bq3b==2
replace POLIO_DO=9 if (s3bq3b==. & (s3bq4b==2|s3bq4b==4))
tab POLIO_DO, miss
/*CHECK : Consistently coded; 663 missing values
1. Coded as 9'unspecified number of doses' if response was 'incomplete' or 'do not know'
2. Coded As 0"no dose" if response was 'NOT GIVEN'/'NOT APPLICABLE'
3. Coded As 3"three doses" if response was 'complete set'
4. No observations coded as 1, 2 or 4*/
*-------------------------------------------------
*DPT_DOSE
tab s3bq3a, miss
*CHECK: Consistently coded; 1,413 missing values
tab s3bq4a, miss
*CHECK: Consistently coded; 2,828 missing values
tab s3bq3a s3bq4a, miss
/*CHECK: Consistently coded - 
s3bq4b is coded only if s3bq3b is missing except 3 observations*/
gen DPT_DOSE = 0 if (s3bq3a==3|s3bq3a==4)
replace DPT_DOSE=0 if (s3bq3a==. & (s3bq4a==3|s3bq4a==5))
replace DPT_DOSE=3 if s3bq3a==1
replace DPT_DOSE=3 if (s3bq3a==. & s3bq4a==1)
replace DPT_DOSE=9 if s3bq3a==2
replace DPT_DOSE=9 if (s3bq3a==. & (s3bq4a==2|s3bq4a==4))
tab DPT_DOSE, miss
/*CHECK : Consistently coded; 665 missing values
1. Coded as 9'unspecified number of doses' if response was 'incomplete' or 'do not know'
2. Coded As 0"no dose" if response was 'NOT GIVEN'/'NOT APPLICABLE'
3. Coded As 3"three doses" if response was 'complete set'
4. No observations coded as 1, 2 or 4*/
*-------------------------------------------------
*MEASLES
tab s3bq3c, miss
*CHECK: Consistently coded; 1,412 missing values
tab s3bq4c, miss
*CHECK: Consistently coded; 2,827 missing values
tab s3bq3c s3bq4c, miss
/*CHECK: Consistently coded - 
s3bq4b is coded only if s3bq3b is missing except 2 observations*/
recode s3bq3c (1=1)(2 3 4=0), gen (MEASLES)
replace MEASLES=1 if (s3bq4c==1 & s3bq3c==.)
replace MEASLES=0 if ((s3bq4c==2|s3bq4c==3|s3bq4c==5) & s3bq3c==.)
replace MEASLES=9 if (s3bq4c==4 & s3bq3c==.)
tab MEASLES, miss
/*CHECK: Consistently coded; 662 missing values
1. Incomplete immunization has been coded as 0'No'
2. Responses as N/A has been coded as 0'No'*/
*-------------------------------------------------
*VACCINE
tab s3bq1, miss
*CHECK: Consistently coded; 28 missing values
recode s3bq1 (1=3)(2=4), gen (VACCINE)
replace VACCINE=2 if (BCG==1| ///
	(POLIO_DO!=0 & POLIO_DO!=.)| ///
	(DPT_DOSE!=0 & DPT_DOSE!=.)| ///
	MEASLES==1)
replace VACCINE=1 if (BCG==1 & POLIO_DO==3 & DPT_DOSE==3 & MEASLES==1)
replace VACCINE=4 if (BCG==0 & POLIO_DO==0 & DPT_DOSE==0 & MEASLES==0)
tab VACCINE, miss
*CHECK: Consistently coded; 21 missing values
*-------------------------------------------------
*WEIGHT
gen WEIGHT =.
*-------------------------------------------------
*HEIGHT
gen HEIGHT=.
*-------------------------------------------------
sort HID INDID
merge HID INDID using 04_AGGDATA\GHA_I
tab _merge
/*CHECK: Correctly merged
2= 16,682
3= 3,579*/
drop _merge
codebook HID
*Number of households 4,523
*--------------------------------------
label var COUNTRY "Country code"
label var REGION "Region"
label var PROVINCE "Province"
label var DISTRICT "District"
label var HID "Household unique identification"
label var SURVEYR "Year of survey"
label var RURURB "Area of residence"
label var HHSIZE "Household members"
label var HHSIZE_S "Household members including household help"
label var WTA_HH "Individual weighting coefficient"
label var WTA_POP "Population weighting coefficient"
label var INDID "Individual identification"
label def sex 0"Female" 1"Male"
label val SEX sex
label var SEX "Sex"
label def relation 1"Head" ///
	2"Spouse" ///
	3"Child" ///
	4"Father/Mother" ///
	5"Grandchild" ///
	6"Son/Daughter in law" ///
	7"Other relative" ///
	8"Domestic help/Paying boarder" ///
	9"Non-relative"
label val RELAT relation
label var RELAT "Relationship to household head"
label def yn 1"Yes"0"No"
label val HEAD yn
label var HEAD "Household head"
label def mstatus 1"Never married" ///
	2"Married monogamous" ///
	3"Married polygamous" ///
	4"Common law,Living together" ///
	5"Divorced/Separated" ///
	6"Widowed"
label val MARSTAT mstatus
label var MARSTAT "Marital status"
label val SP_PRES yn
label var SP_PRES "Spouse present"
label var AGEY "Age in completed years"
label var ETHNICITY "Ethnicity"
label var LANGUAGE "Language"
label var RELIGION "Religion"
label def litstat 1"Can read or write" ///
	2"Cannot read or write" ///
	3"Cannot be determined"
label val LITERACY litstat
label var LITERACY "Literacy status"
label val EVERATTD yn
label var EVERATTD "Ever attended school"
label val ATSCHOOL yn
label var ATSCHOOL "Current school enrollment"
label def edlev 0"No education" ///
	1"Pre-school/ primary, not completed" ///
	2"Completed primary, but less than completed lower secondary" ///
	3"Completed lower secondary but less than completed upper secondary" ///
	4"Completed upper secondary" ///
	5"Post-secondary technical" ///
	6"University and higher" ///
	7"Formal adult education/litracy program" ///
	9"Other"
label val EDLEVEL_AR edlev
label var EDLEVEL_AR "Highest level of education completed"
label var EDYEARS "Years of education"
label var EDYEARS_AT "Years of education for currently enrolled"
label def schltyp 1"Public" ///
	2"Private" ///
	9"Other"
label val SCHLTYP schltyp
label var SCHLTYP "Type of school attending"
label var MORB_TR "Time reference for variable MORBID (weeks)"
label val MORBID yn
label var MORBID "Morbidity last MORB_TR(weeks)"
label val RTREATM yn
label var RTREATM "Sought medical attention"
label def hlthfac 1"Hospital" ///
	2"Clinics" ///
	3"Dispensary, health center, health post" ///
	4"Outreach" ///
	5"Pharmacy" ///
	6"Traditional healer" ///
	9"Other"
label val HLTHFAC hlthfac
label var HLTHFAC "Health provider visited"
label def owhprovd 1"Public" ///
	2"Private-modern medicine" ///
	3"Private-Traditional healer" ///
	4"Missionary/NGO" ///
	9"Other"
label val OWHPROVD owhprovd
label var OWHPROVD "Ownership of health provider visited"
label var AGEM "Age of child in completed months"
label def whdeliv 1"Trained birth attendant" ///
	2"Traditional birth attendant" ///
	3"Relative/ friend" ///
	9"Other"
label val WHDELIV whdeliv
label var WHDELIV "Who helped assist childbirth"
label def vcard 1"Yes" ///
	2"No, but child vaccinated" ///
	3"No, child never vaccinated" ///
	9"Other"
label val VCARD vcard
label var VCARD "Does the child have a Vaccine Card"
label def bcg 1"Yes" ///
	0"No" ///
	3"No, child never vaccinated" ///
	9"Dont know"
label val BCG bcg
label var BCG "Child immunized against BCG"
label def polio 0"No dose" ///
	1"One dose" ///
	2"Two doses" ///
	3"Three doses" ///
	4"More than three doses" ///
	9"Unspecified number of doses"
label val POLIO_DO polio
label var POLIO_DO "Number of doses of Polio received"
label def dpt_dose 0"No dose" ///
	1"One dose" ///
	2"Two doses" ///
	3"Three doses" ///
	4"More than three doses" ///
	9"Unspecified number of doses"
label val DPT_DOSE dpt_dose
label var DPT_DOSE "Number of doses of DPT received"
label def measles  1"Yes" ///
	0"No" ///
	9"Dont know"
label val MEASLES measles 
label var MEASLES "Child immunized against Measles"
label def vaccine  1"Fully immunized" ///
	2"Partially immunized" ///
	3"Immunized but no information on completeness" ///
	4"Not immunized"
label val VACCINE vaccine
label var VACCINE "Immunization status of child"
label var WEIGHT "Weight of the child (Kg)"
label var HEIGHT "Height of the child (cms)"
*--------------------------------------------------
order COUNTRY REGION PROVINCE DISTRICT HID SURVEYR ///
	RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP INDID SEX RELAT HEAD ///
	MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION ///
	LITERACY EVERATTD ATSCHOOL EDLEVEL_AR EDYEARS EDYEARS_AT ///
	SCHLTYP MORB_TR MORBID RTREATM HLTHFAC OWHPROVD AGEM WHDELIV ///
	VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT
	
keep COUNTRY REGION PROVINCE DISTRICT HID SURVEYR ///
	RURURB HHSIZE HHSIZE_S WTA_HH WTA_POP INDID SEX RELAT HEAD ///
	MARSTAT SP_PRES AGEY ETHNICITY LANGUAGE RELIGION ///
	LITERACY EVERATTD ATSCHOOL EDLEVEL_AR EDYEARS EDYEARS_AT ///
	SCHLTYP MORB_TR MORBID RTREATM HLTHFAC OWHPROVD AGEM WHDELIV ///
	VCARD BCG POLIO_DO DPT_DOSE MEASLES VACCINE WEIGHT HEIGHT
*-------------------------------------------------
sort HID INDID
count
*number of observations 20,261
save 04_AGGDATA\GHA_1991_I, replace
erase 04_AGGDATA\GHA_I.dta
